// Calcul une approximation d'intgrale

function y = f(x)
//===============
//y = x^3-1/4;
y = sin(%pi*x)*%pi - 2;
endfunction;

function approxInt = Rectangle(a,b,n)
//==================================
// calcul une approximation de l'intgrale de  a    b
// de la fonction  f,  par dcoupage en  n  rectangles.
h = (b - a) / n;
sum = 0;
for x = a+h/2:h:b-h/2 do
  sum = sum + f(x);
end;

approxInt = sum * h;
endfunction;

function approxInt = Triangle(a,b,n)
//==================================
// calcul une approximation de l'intgrale de  a    b
// de la fonction  f,  par dcoupage en  n  triangles.
h = (b - a) / n;
sum = (f(a) + f(b)) / 2;
for x = a+h:h:b-h do
  sum = sum + f(x);
end;

approxInt = sum * h;
endfunction;

function approxInt = Ordre4(a,b,n)
//================================
// calcul une approximation d'ordre 4 de l'intgrale de  a    b
// de la fonction  f,  en  n  valuations de  f.
h = (b - a) / n;
sum = (9*(f(a) + f(b)) + 28*(f(a+h) + f(b-h)) +..
       23*(f(a+2*h) + f(b-2*h))) / 24 ;

for k = 3:n-3 do
  sum = sum + f(a + k*h);
end;

approxInt = sum * h;
endfunction;

function approxInt = Ordre6(a,b,n)
//================================
// calcul une approximation d'ordre 6 de l'intgrale de  a    b
// de la fonction  f,  en  n  valuations de  f.
h = (b - a) / n;
sum = (f(a    ) + f(b    ))* 95/288 +..
      (f(a+  h) + f(b-  h))*317/240 +..
      (f(a+2*h) + f(b-2*h))* 23/30 +..
      (f(a+3*h) + f(b-3*h))*793/720 +..
      (f(a+4*h) + f(b-4*h))*157/160;

for k = 5:n-5 do
  sum = sum + f(a + k*h);
end;

approxInt = sum * h;
endfunction;

nbIntervals = 10;
Approx1 = Rectangle(0, 1, nbIntervals);
Approx2 = Triangle(0, 1, nbIntervals);
Approx4 = Ordre4(0, 1, nbIntervals);
Approx6 = Ordre6(0, 1, nbIntervals);
disp(Approx1);
disp(Approx2);
disp((Approx1 + Approx2) / 2);
disp(Approx4);
disp(Approx6);
